@@ -3,9 +3,9 @@ Main interface for backup service type definitions.
 
 Usage::
 
-    from mypy_boto3.backup.type_defs import LifecycleTypeDef
+    from mypy_boto3.backup.type_defs import BackupJobTypeDef
 
-    data: LifecycleTypeDef = {...}
+    data: BackupJobTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,29 +22,38 @@ else:
 
 
 __all__ = (
-    "LifecycleTypeDef",
-    "CopyActionTypeDef",
+    "BackupJobTypeDef",
+    "BackupPlanTemplatesListMemberTypeDef",
+    "BackupPlanTypeDef",
+    "BackupPlansListMemberTypeDef",
     "BackupRuleInputTypeDef",
-    "BackupPlanInputTypeDef",
-    "ConditionTypeDef",
+    "BackupRuleTypeDef",
     "BackupSelectionTypeDef",
+    "BackupSelectionsListMemberTypeDef",
+    "BackupVaultListMemberTypeDef",
+    "CalculatedLifecycleTypeDef",
+    "ConditionTypeDef",
+    "CopyActionTypeDef",
+    "CopyJobTypeDef",
+    "LifecycleTypeDef",
+    "ProtectedResourceTypeDef",
+    "RecoveryPointByBackupVaultTypeDef",
+    "RecoveryPointByResourceTypeDef",
+    "RecoveryPointCreatorTypeDef",
+    "RestoreJobsListMemberTypeDef",
+    "BackupPlanInputTypeDef",
     "CreateBackupPlanOutputTypeDef",
     "CreateBackupSelectionOutputTypeDef",
     "CreateBackupVaultOutputTypeDef",
     "DeleteBackupPlanOutputTypeDef",
-    "RecoveryPointCreatorTypeDef",
     "DescribeBackupJobOutputTypeDef",
     "DescribeBackupVaultOutputTypeDef",
-    "CopyJobTypeDef",
     "DescribeCopyJobOutputTypeDef",
     "DescribeProtectedResourceOutputTypeDef",
-    "CalculatedLifecycleTypeDef",
     "DescribeRecoveryPointOutputTypeDef",
     "DescribeRegionSettingsOutputTypeDef",
     "DescribeRestoreJobOutputTypeDef",
     "ExportBackupPlanTemplateOutputTypeDef",
-    "BackupRuleTypeDef",
-    "BackupPlanTypeDef",
     "GetBackupPlanFromJSONOutputTypeDef",
     "GetBackupPlanFromTemplateOutputTypeDef",
     "GetBackupPlanOutputTypeDef",
@@ -53,25 +62,16 @@ __all__ = (
     "GetBackupVaultNotificationsOutputTypeDef",
     "GetRecoveryPointRestoreMetadataOutputTypeDef",
     "GetSupportedResourceTypesOutputTypeDef",
-    "BackupJobTypeDef",
     "ListBackupJobsOutputTypeDef",
-    "BackupPlanTemplatesListMemberTypeDef",
     "ListBackupPlanTemplatesOutputTypeDef",
-    "BackupPlansListMemberTypeDef",
     "ListBackupPlanVersionsOutputTypeDef",
     "ListBackupPlansOutputTypeDef",
-    "BackupSelectionsListMemberTypeDef",
     "ListBackupSelectionsOutputTypeDef",
-    "BackupVaultListMemberTypeDef",
     "ListBackupVaultsOutputTypeDef",
     "ListCopyJobsOutputTypeDef",
-    "ProtectedResourceTypeDef",
     "ListProtectedResourcesOutputTypeDef",
-    "RecoveryPointByBackupVaultTypeDef",
     "ListRecoveryPointsByBackupVaultOutputTypeDef",
-    "RecoveryPointByResourceTypeDef",
     "ListRecoveryPointsByResourceOutputTypeDef",
-    "RestoreJobsListMemberTypeDef",
     "ListRestoreJobsOutputTypeDef",
     "ListTagsOutputTypeDef",
     "StartBackupJobOutputTypeDef",
@@ -81,21 +81,56 @@ __all__ = (
     "UpdateRecoveryPointLifecycleOutputTypeDef",
 )
 
-LifecycleTypeDef = TypedDict(
-    "LifecycleTypeDef", {"MoveToColdStorageAfterDays": int, "DeleteAfterDays": int}, total=False
+BackupJobTypeDef = TypedDict(
+    "BackupJobTypeDef",
+    {
+        "BackupJobId": str,
+        "BackupVaultName": str,
+        "BackupVaultArn": str,
+        "RecoveryPointArn": str,
+        "ResourceArn": str,
+        "CreationDate": datetime,
+        "CompletionDate": datetime,
+        "State": Literal[
+            "CREATED", "PENDING", "RUNNING", "ABORTING", "ABORTED", "COMPLETED", "FAILED", "EXPIRED"
+        ],
+        "StatusMessage": str,
+        "PercentDone": str,
+        "BackupSizeInBytes": int,
+        "IamRoleArn": str,
+        "CreatedBy": "RecoveryPointCreatorTypeDef",
+        "ExpectedCompletionDate": datetime,
+        "StartBy": datetime,
+        "ResourceType": str,
+        "BytesTransferred": int,
+    },
+    total=False,
 )
 
-_RequiredCopyActionTypeDef = TypedDict(
-    "_RequiredCopyActionTypeDef", {"DestinationBackupVaultArn": str}
-)
-_OptionalCopyActionTypeDef = TypedDict(
-    "_OptionalCopyActionTypeDef", {"Lifecycle": LifecycleTypeDef}, total=False
+BackupPlanTemplatesListMemberTypeDef = TypedDict(
+    "BackupPlanTemplatesListMemberTypeDef",
+    {"BackupPlanTemplateId": str, "BackupPlanTemplateName": str},
+    total=False,
 )
 
+BackupPlanTypeDef = TypedDict(
+    "BackupPlanTypeDef", {"BackupPlanName": str, "Rules": List["BackupRuleTypeDef"]}
+)
 
-class CopyActionTypeDef(_RequiredCopyActionTypeDef, _OptionalCopyActionTypeDef):
-    pass
-
+BackupPlansListMemberTypeDef = TypedDict(
+    "BackupPlansListMemberTypeDef",
+    {
+        "BackupPlanArn": str,
+        "BackupPlanId": str,
+        "CreationDate": datetime,
+        "DeletionDate": datetime,
+        "VersionId": str,
+        "BackupPlanName": str,
+        "CreatorRequestId": str,
+        "LastExecutionDate": datetime,
+    },
+    total=False,
+)
 
 _RequiredBackupRuleInputTypeDef = TypedDict(
     "_RequiredBackupRuleInputTypeDef", {"RuleName": str, "TargetBackupVaultName": str}
@@ -106,9 +141,9 @@ _OptionalBackupRuleInputTypeDef = TypedDict(
         "ScheduleExpression": str,
         "StartWindowMinutes": int,
         "CompletionWindowMinutes": int,
-        "Lifecycle": LifecycleTypeDef,
+        "Lifecycle": "LifecycleTypeDef",
         "RecoveryPointTags": Dict[str, str],
-        "CopyActions": List[CopyActionTypeDef],
+        "CopyActions": List["CopyActionTypeDef"],
     },
     total=False,
 )
@@ -118,21 +153,34 @@ class BackupRuleInputTypeDef(_RequiredBackupRuleInputTypeDef, _OptionalBackupRul
     pass
 
 
-BackupPlanInputTypeDef = TypedDict(
-    "BackupPlanInputTypeDef", {"BackupPlanName": str, "Rules": List[BackupRuleInputTypeDef]}
+_RequiredBackupRuleTypeDef = TypedDict(
+    "_RequiredBackupRuleTypeDef", {"RuleName": str, "TargetBackupVaultName": str}
+)
+_OptionalBackupRuleTypeDef = TypedDict(
+    "_OptionalBackupRuleTypeDef",
+    {
+        "ScheduleExpression": str,
+        "StartWindowMinutes": int,
+        "CompletionWindowMinutes": int,
+        "Lifecycle": "LifecycleTypeDef",
+        "RecoveryPointTags": Dict[str, str],
+        "RuleId": str,
+        "CopyActions": List["CopyActionTypeDef"],
+    },
+    total=False,
 )
 
-ConditionTypeDef = TypedDict(
-    "ConditionTypeDef",
-    {"ConditionType": Literal["STRINGEQUALS"], "ConditionKey": str, "ConditionValue": str},
-)
+
+class BackupRuleTypeDef(_RequiredBackupRuleTypeDef, _OptionalBackupRuleTypeDef):
+    pass
+
 
 _RequiredBackupSelectionTypeDef = TypedDict(
     "_RequiredBackupSelectionTypeDef", {"SelectionName": str, "IamRoleArn": str}
 )
 _OptionalBackupSelectionTypeDef = TypedDict(
     "_OptionalBackupSelectionTypeDef",
-    {"Resources": List[str], "ListOfTags": List[ConditionTypeDef]},
+    {"Resources": List[str], "ListOfTags": List["ConditionTypeDef"]},
     total=False,
 )
 
@@ -141,6 +189,150 @@ class BackupSelectionTypeDef(_RequiredBackupSelectionTypeDef, _OptionalBackupSel
     pass
 
 
+BackupSelectionsListMemberTypeDef = TypedDict(
+    "BackupSelectionsListMemberTypeDef",
+    {
+        "SelectionId": str,
+        "SelectionName": str,
+        "BackupPlanId": str,
+        "CreationDate": datetime,
+        "CreatorRequestId": str,
+        "IamRoleArn": str,
+    },
+    total=False,
+)
+
+BackupVaultListMemberTypeDef = TypedDict(
+    "BackupVaultListMemberTypeDef",
+    {
+        "BackupVaultName": str,
+        "BackupVaultArn": str,
+        "CreationDate": datetime,
+        "EncryptionKeyArn": str,
+        "CreatorRequestId": str,
+        "NumberOfRecoveryPoints": int,
+    },
+    total=False,
+)
+
+CalculatedLifecycleTypeDef = TypedDict(
+    "CalculatedLifecycleTypeDef",
+    {"MoveToColdStorageAt": datetime, "DeleteAt": datetime},
+    total=False,
+)
+
+ConditionTypeDef = TypedDict(
+    "ConditionTypeDef",
+    {"ConditionType": Literal["STRINGEQUALS"], "ConditionKey": str, "ConditionValue": str},
+)
+
+_RequiredCopyActionTypeDef = TypedDict(
+    "_RequiredCopyActionTypeDef", {"DestinationBackupVaultArn": str}
+)
+_OptionalCopyActionTypeDef = TypedDict(
+    "_OptionalCopyActionTypeDef", {"Lifecycle": "LifecycleTypeDef"}, total=False
+)
+
+
+class CopyActionTypeDef(_RequiredCopyActionTypeDef, _OptionalCopyActionTypeDef):
+    pass
+
+
+CopyJobTypeDef = TypedDict(
+    "CopyJobTypeDef",
+    {
+        "CopyJobId": str,
+        "SourceBackupVaultArn": str,
+        "SourceRecoveryPointArn": str,
+        "DestinationBackupVaultArn": str,
+        "DestinationRecoveryPointArn": str,
+        "ResourceArn": str,
+        "CreationDate": datetime,
+        "CompletionDate": datetime,
+        "State": Literal["CREATED", "RUNNING", "COMPLETED", "FAILED"],
+        "StatusMessage": str,
+        "BackupSizeInBytes": int,
+        "IamRoleArn": str,
+        "CreatedBy": "RecoveryPointCreatorTypeDef",
+        "ResourceType": str,
+    },
+    total=False,
+)
+
+LifecycleTypeDef = TypedDict(
+    "LifecycleTypeDef", {"MoveToColdStorageAfterDays": int, "DeleteAfterDays": int}, total=False
+)
+
+ProtectedResourceTypeDef = TypedDict(
+    "ProtectedResourceTypeDef",
+    {"ResourceArn": str, "ResourceType": str, "LastBackupTime": datetime},
+    total=False,
+)
+
+RecoveryPointByBackupVaultTypeDef = TypedDict(
+    "RecoveryPointByBackupVaultTypeDef",
+    {
+        "RecoveryPointArn": str,
+        "BackupVaultName": str,
+        "BackupVaultArn": str,
+        "ResourceArn": str,
+        "ResourceType": str,
+        "CreatedBy": "RecoveryPointCreatorTypeDef",
+        "IamRoleArn": str,
+        "Status": Literal["COMPLETED", "PARTIAL", "DELETING", "EXPIRED"],
+        "CreationDate": datetime,
+        "CompletionDate": datetime,
+        "BackupSizeInBytes": int,
+        "CalculatedLifecycle": "CalculatedLifecycleTypeDef",
+        "Lifecycle": "LifecycleTypeDef",
+        "EncryptionKeyArn": str,
+        "IsEncrypted": bool,
+        "LastRestoreTime": datetime,
+    },
+    total=False,
+)
+
+RecoveryPointByResourceTypeDef = TypedDict(
+    "RecoveryPointByResourceTypeDef",
+    {
+        "RecoveryPointArn": str,
+        "CreationDate": datetime,
+        "Status": Literal["COMPLETED", "PARTIAL", "DELETING", "EXPIRED"],
+        "EncryptionKeyArn": str,
+        "BackupSizeBytes": int,
+        "BackupVaultName": str,
+    },
+    total=False,
+)
+
+RecoveryPointCreatorTypeDef = TypedDict(
+    "RecoveryPointCreatorTypeDef",
+    {"BackupPlanId": str, "BackupPlanArn": str, "BackupPlanVersion": str, "BackupRuleId": str},
+    total=False,
+)
+
+RestoreJobsListMemberTypeDef = TypedDict(
+    "RestoreJobsListMemberTypeDef",
+    {
+        "RestoreJobId": str,
+        "RecoveryPointArn": str,
+        "CreationDate": datetime,
+        "CompletionDate": datetime,
+        "Status": Literal["PENDING", "RUNNING", "COMPLETED", "ABORTED", "FAILED"],
+        "StatusMessage": str,
+        "PercentDone": str,
+        "BackupSizeInBytes": int,
+        "IamRoleArn": str,
+        "ExpectedCompletionTimeMinutes": int,
+        "CreatedResourceArn": str,
+    },
+    total=False,
+)
+
+BackupPlanInputTypeDef = TypedDict(
+    "BackupPlanInputTypeDef", {"BackupPlanName": str, "Rules": List["BackupRuleInputTypeDef"]}
+)
+
 CreateBackupPlanOutputTypeDef = TypedDict(
     "CreateBackupPlanOutputTypeDef",
     {"BackupPlanId": str, "BackupPlanArn": str, "CreationDate": datetime, "VersionId": str},
@@ -165,12 +357,6 @@ DeleteBackupPlanOutputTypeDef = TypedDict(
     total=False,
 )
 
-RecoveryPointCreatorTypeDef = TypedDict(
-    "RecoveryPointCreatorTypeDef",
-    {"BackupPlanId": str, "BackupPlanArn": str, "BackupPlanVersion": str, "BackupRuleId": str},
-    total=False,
-)
-
 DescribeBackupJobOutputTypeDef = TypedDict(
     "DescribeBackupJobOutputTypeDef",
     {
@@ -188,7 +374,7 @@ DescribeBackupJobOutputTypeDef = TypedDict(
         "PercentDone": str,
         "BackupSizeInBytes": int,
         "IamRoleArn": str,
-        "CreatedBy": RecoveryPointCreatorTypeDef,
+        "CreatedBy": "RecoveryPointCreatorTypeDef",
         "ResourceType": str,
         "BytesTransferred": int,
         "ExpectedCompletionDate": datetime,
@@ -210,29 +396,8 @@ DescribeBackupVaultOutputTypeDef = TypedDict(
     total=False,
 )
 
-CopyJobTypeDef = TypedDict(
-    "CopyJobTypeDef",
-    {
-        "CopyJobId": str,
-        "SourceBackupVaultArn": str,
-        "SourceRecoveryPointArn": str,
-        "DestinationBackupVaultArn": str,
-        "DestinationRecoveryPointArn": str,
-        "ResourceArn": str,
-        "CreationDate": datetime,
-        "CompletionDate": datetime,
-        "State": Literal["CREATED", "RUNNING", "COMPLETED", "FAILED"],
-        "StatusMessage": str,
-        "BackupSizeInBytes": int,
-        "IamRoleArn": str,
-        "CreatedBy": RecoveryPointCreatorTypeDef,
-        "ResourceType": str,
-    },
-    total=False,
-)
-
 DescribeCopyJobOutputTypeDef = TypedDict(
-    "DescribeCopyJobOutputTypeDef", {"CopyJob": CopyJobTypeDef}, total=False
+    "DescribeCopyJobOutputTypeDef", {"CopyJob": "CopyJobTypeDef"}, total=False
 )
 
 DescribeProtectedResourceOutputTypeDef = TypedDict(
@@ -241,12 +406,6 @@ DescribeProtectedResourceOutputTypeDef = TypedDict(
     total=False,
 )
 
-CalculatedLifecycleTypeDef = TypedDict(
-    "CalculatedLifecycleTypeDef",
-    {"MoveToColdStorageAt": datetime, "DeleteAt": datetime},
-    total=False,
-)
-
 DescribeRecoveryPointOutputTypeDef = TypedDict(
     "DescribeRecoveryPointOutputTypeDef",
     {
@@ -255,14 +414,14 @@ DescribeRecoveryPointOutputTypeDef = TypedDict(
         "BackupVaultArn": str,
         "ResourceArn": str,
         "ResourceType": str,
-        "CreatedBy": RecoveryPointCreatorTypeDef,
+        "CreatedBy": "RecoveryPointCreatorTypeDef",
         "IamRoleArn": str,
         "Status": Literal["COMPLETED", "PARTIAL", "DELETING", "EXPIRED"],
         "CreationDate": datetime,
         "CompletionDate": datetime,
         "BackupSizeInBytes": int,
-        "CalculatedLifecycle": CalculatedLifecycleTypeDef,
-        "Lifecycle": LifecycleTypeDef,
+        "CalculatedLifecycle": "CalculatedLifecycleTypeDef",
+        "Lifecycle": "LifecycleTypeDef",
         "EncryptionKeyArn": str,
         "IsEncrypted": bool,
         "StorageClass": Literal["WARM", "COLD", "DELETED"],
@@ -299,44 +458,20 @@ ExportBackupPlanTemplateOutputTypeDef = TypedDict(
     "ExportBackupPlanTemplateOutputTypeDef", {"BackupPlanTemplateJson": str}, total=False
 )
 
-_RequiredBackupRuleTypeDef = TypedDict(
-    "_RequiredBackupRuleTypeDef", {"RuleName": str, "TargetBackupVaultName": str}
-)
-_OptionalBackupRuleTypeDef = TypedDict(
-    "_OptionalBackupRuleTypeDef",
-    {
-        "ScheduleExpression": str,
-        "StartWindowMinutes": int,
-        "CompletionWindowMinutes": int,
-        "Lifecycle": LifecycleTypeDef,
-        "RecoveryPointTags": Dict[str, str],
-        "RuleId": str,
-        "CopyActions": List[CopyActionTypeDef],
-    },
-    total=False,
-)
-
-
-class BackupRuleTypeDef(_RequiredBackupRuleTypeDef, _OptionalBackupRuleTypeDef):
-    pass
-
-
-BackupPlanTypeDef = TypedDict(
-    "BackupPlanTypeDef", {"BackupPlanName": str, "Rules": List[BackupRuleTypeDef]}
-)
-
 GetBackupPlanFromJSONOutputTypeDef = TypedDict(
-    "GetBackupPlanFromJSONOutputTypeDef", {"BackupPlan": BackupPlanTypeDef}, total=False
+    "GetBackupPlanFromJSONOutputTypeDef", {"BackupPlan": "BackupPlanTypeDef"}, total=False
 )
 
 GetBackupPlanFromTemplateOutputTypeDef = TypedDict(
-    "GetBackupPlanFromTemplateOutputTypeDef", {"BackupPlanDocument": BackupPlanTypeDef}, total=False
+    "GetBackupPlanFromTemplateOutputTypeDef",
+    {"BackupPlanDocument": "BackupPlanTypeDef"},
+    total=False,
 )
 
 GetBackupPlanOutputTypeDef = TypedDict(
     "GetBackupPlanOutputTypeDef",
     {
-        "BackupPlan": BackupPlanTypeDef,
+        "BackupPlan": "BackupPlanTypeDef",
         "BackupPlanId": str,
         "BackupPlanArn": str,
         "VersionId": str,
@@ -351,7 +486,7 @@ GetBackupPlanOutputTypeDef = TypedDict(
 GetBackupSelectionOutputTypeDef = TypedDict(
     "GetBackupSelectionOutputTypeDef",
     {
-        "BackupSelection": BackupSelectionTypeDef,
+        "BackupSelection": "BackupSelectionTypeDef",
         "SelectionId": str,
         "BackupPlanId": str,
         "CreationDate": datetime,
@@ -405,200 +540,67 @@ GetSupportedResourceTypesOutputTypeDef = TypedDict(
     "GetSupportedResourceTypesOutputTypeDef", {"ResourceTypes": List[str]}, total=False
 )
 
-BackupJobTypeDef = TypedDict(
-    "BackupJobTypeDef",
-    {
-        "BackupJobId": str,
-        "BackupVaultName": str,
-        "BackupVaultArn": str,
-        "RecoveryPointArn": str,
-        "ResourceArn": str,
-        "CreationDate": datetime,
-        "CompletionDate": datetime,
-        "State": Literal[
-            "CREATED", "PENDING", "RUNNING", "ABORTING", "ABORTED", "COMPLETED", "FAILED", "EXPIRED"
-        ],
-        "StatusMessage": str,
-        "PercentDone": str,
-        "BackupSizeInBytes": int,
-        "IamRoleArn": str,
-        "CreatedBy": RecoveryPointCreatorTypeDef,
-        "ExpectedCompletionDate": datetime,
-        "StartBy": datetime,
-        "ResourceType": str,
-        "BytesTransferred": int,
-    },
-    total=False,
-)
-
 ListBackupJobsOutputTypeDef = TypedDict(
     "ListBackupJobsOutputTypeDef",
-    {"BackupJobs": List[BackupJobTypeDef], "NextToken": str},
-    total=False,
-)
-
-BackupPlanTemplatesListMemberTypeDef = TypedDict(
-    "BackupPlanTemplatesListMemberTypeDef",
-    {"BackupPlanTemplateId": str, "BackupPlanTemplateName": str},
+    {"BackupJobs": List["BackupJobTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListBackupPlanTemplatesOutputTypeDef = TypedDict(
     "ListBackupPlanTemplatesOutputTypeDef",
-    {"NextToken": str, "BackupPlanTemplatesList": List[BackupPlanTemplatesListMemberTypeDef]},
-    total=False,
-)
-
-BackupPlansListMemberTypeDef = TypedDict(
-    "BackupPlansListMemberTypeDef",
-    {
-        "BackupPlanArn": str,
-        "BackupPlanId": str,
-        "CreationDate": datetime,
-        "DeletionDate": datetime,
-        "VersionId": str,
-        "BackupPlanName": str,
-        "CreatorRequestId": str,
-        "LastExecutionDate": datetime,
-    },
+    {"NextToken": str, "BackupPlanTemplatesList": List["BackupPlanTemplatesListMemberTypeDef"]},
     total=False,
 )
 
 ListBackupPlanVersionsOutputTypeDef = TypedDict(
     "ListBackupPlanVersionsOutputTypeDef",
-    {"NextToken": str, "BackupPlanVersionsList": List[BackupPlansListMemberTypeDef]},
+    {"NextToken": str, "BackupPlanVersionsList": List["BackupPlansListMemberTypeDef"]},
     total=False,
 )
 
 ListBackupPlansOutputTypeDef = TypedDict(
     "ListBackupPlansOutputTypeDef",
-    {"NextToken": str, "BackupPlansList": List[BackupPlansListMemberTypeDef]},
-    total=False,
-)
-
-BackupSelectionsListMemberTypeDef = TypedDict(
-    "BackupSelectionsListMemberTypeDef",
-    {
-        "SelectionId": str,
-        "SelectionName": str,
-        "BackupPlanId": str,
-        "CreationDate": datetime,
-        "CreatorRequestId": str,
-        "IamRoleArn": str,
-    },
+    {"NextToken": str, "BackupPlansList": List["BackupPlansListMemberTypeDef"]},
     total=False,
 )
 
 ListBackupSelectionsOutputTypeDef = TypedDict(
     "ListBackupSelectionsOutputTypeDef",
-    {"NextToken": str, "BackupSelectionsList": List[BackupSelectionsListMemberTypeDef]},
-    total=False,
-)
-
-BackupVaultListMemberTypeDef = TypedDict(
-    "BackupVaultListMemberTypeDef",
-    {
-        "BackupVaultName": str,
-        "BackupVaultArn": str,
-        "CreationDate": datetime,
-        "EncryptionKeyArn": str,
-        "CreatorRequestId": str,
-        "NumberOfRecoveryPoints": int,
-    },
+    {"NextToken": str, "BackupSelectionsList": List["BackupSelectionsListMemberTypeDef"]},
     total=False,
 )
 
 ListBackupVaultsOutputTypeDef = TypedDict(
     "ListBackupVaultsOutputTypeDef",
-    {"BackupVaultList": List[BackupVaultListMemberTypeDef], "NextToken": str},
+    {"BackupVaultList": List["BackupVaultListMemberTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListCopyJobsOutputTypeDef = TypedDict(
-    "ListCopyJobsOutputTypeDef", {"CopyJobs": List[CopyJobTypeDef], "NextToken": str}, total=False
-)
-
-ProtectedResourceTypeDef = TypedDict(
-    "ProtectedResourceTypeDef",
-    {"ResourceArn": str, "ResourceType": str, "LastBackupTime": datetime},
-    total=False,
+    "ListCopyJobsOutputTypeDef", {"CopyJobs": List["CopyJobTypeDef"], "NextToken": str}, total=False
 )
 
 ListProtectedResourcesOutputTypeDef = TypedDict(
     "ListProtectedResourcesOutputTypeDef",
-    {"Results": List[ProtectedResourceTypeDef], "NextToken": str},
-    total=False,
-)
-
-RecoveryPointByBackupVaultTypeDef = TypedDict(
-    "RecoveryPointByBackupVaultTypeDef",
-    {
-        "RecoveryPointArn": str,
-        "BackupVaultName": str,
-        "BackupVaultArn": str,
-        "ResourceArn": str,
-        "ResourceType": str,
-        "CreatedBy": RecoveryPointCreatorTypeDef,
-        "IamRoleArn": str,
-        "Status": Literal["COMPLETED", "PARTIAL", "DELETING", "EXPIRED"],
-        "CreationDate": datetime,
-        "CompletionDate": datetime,
-        "BackupSizeInBytes": int,
-        "CalculatedLifecycle": CalculatedLifecycleTypeDef,
-        "Lifecycle": LifecycleTypeDef,
-        "EncryptionKeyArn": str,
-        "IsEncrypted": bool,
-        "LastRestoreTime": datetime,
-    },
+    {"Results": List["ProtectedResourceTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListRecoveryPointsByBackupVaultOutputTypeDef = TypedDict(
     "ListRecoveryPointsByBackupVaultOutputTypeDef",
-    {"NextToken": str, "RecoveryPoints": List[RecoveryPointByBackupVaultTypeDef]},
-    total=False,
-)
-
-RecoveryPointByResourceTypeDef = TypedDict(
-    "RecoveryPointByResourceTypeDef",
-    {
-        "RecoveryPointArn": str,
-        "CreationDate": datetime,
-        "Status": Literal["COMPLETED", "PARTIAL", "DELETING", "EXPIRED"],
-        "EncryptionKeyArn": str,
-        "BackupSizeBytes": int,
-        "BackupVaultName": str,
-    },
+    {"NextToken": str, "RecoveryPoints": List["RecoveryPointByBackupVaultTypeDef"]},
     total=False,
 )
 
 ListRecoveryPointsByResourceOutputTypeDef = TypedDict(
     "ListRecoveryPointsByResourceOutputTypeDef",
-    {"NextToken": str, "RecoveryPoints": List[RecoveryPointByResourceTypeDef]},
-    total=False,
-)
-
-RestoreJobsListMemberTypeDef = TypedDict(
-    "RestoreJobsListMemberTypeDef",
-    {
-        "RestoreJobId": str,
-        "RecoveryPointArn": str,
-        "CreationDate": datetime,
-        "CompletionDate": datetime,
-        "Status": Literal["PENDING", "RUNNING", "COMPLETED", "ABORTED", "FAILED"],
-        "StatusMessage": str,
-        "PercentDone": str,
-        "BackupSizeInBytes": int,
-        "IamRoleArn": str,
-        "ExpectedCompletionTimeMinutes": int,
-        "CreatedResourceArn": str,
-    },
+    {"NextToken": str, "RecoveryPoints": List["RecoveryPointByResourceTypeDef"]},
     total=False,
 )
 
 ListRestoreJobsOutputTypeDef = TypedDict(
     "ListRestoreJobsOutputTypeDef",
-    {"RestoreJobs": List[RestoreJobsListMemberTypeDef], "NextToken": str},
+    {"RestoreJobs": List["RestoreJobsListMemberTypeDef"], "NextToken": str},
     total=False,
 )
 
@@ -631,8 +633,8 @@ UpdateRecoveryPointLifecycleOutputTypeDef = TypedDict(
     {
         "BackupVaultArn": str,
         "RecoveryPointArn": str,
-        "Lifecycle": LifecycleTypeDef,
-        "CalculatedLifecycle": CalculatedLifecycleTypeDef,
+        "Lifecycle": "LifecycleTypeDef",
+        "CalculatedLifecycle": "CalculatedLifecycleTypeDef",
     },
     total=False,
 )
